<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Admin\Form;

use Laminas\Form\Form;

class AdminUserGroupForm extends Form
{
    public function __construct($name = 'admin-group-form', array $options = [])
    {
        parent::__construct($name, $options);
        $this->setAttribute('method', 'post');
        $this->setAttribute('class', 'form-horizontal');

        $this->addElements();
        $this->addInputFilter();
    }

    protected function addElements()
    {
        foreach (ADMIN_LANGUAGE as $language) {
            $this->add([
                'type'  => 'text',
                'name'  => 'adminGroupName'.$language,
                'attributes'    => [
                    'id'            => 'adminGroupName'.$language,
                    'class'         => 'form-control'
                ]
            ]);
        }

        $this->add([
            'type'  => 'multiCheckbox',
            'name'  => 'adminGroupPermission'
        ]);
    }

    protected function addInputFilter()
    {
        $inputFilter = $this->getInputFilter();

        foreach (ADMIN_LANGUAGE as $language) {
            $inputFilter->add([
                'name'      => 'adminGroupName'.$language,
                'required'  => true,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags'],
                    ['name' => 'HtmlEntities']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 200
                        ]
                    ]
                ]
            ]);
        }

        $inputFilter->add([
            'name'      => 'adminGroupPermission',
            'required'  => false
        ]);
    }
}