<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Admin\Form;

use Admin\Data\MultiLanguage;
use Laminas\Form\Form;

class RegionForm extends Form
{
    public function __construct($name = 'region-form', array $options = [])
    {
        parent::__construct($name, $options);
        $this->setAttribute('method', 'post');
        $this->setAttribute('class', 'form-horizontal');

        $this->addElements();
        $this->addInputFilter();
    }

    protected function addElements()
    {
        if (MultiLanguage::REGION_MULTI_LANGUAGE == 1) {
            foreach (SHOP_LANGUAGE as $language) {
                $this->add([
                    'type'  => 'text',
                    'name'  => 'regionName' . $language,
                    'attributes'    => [
                        'id'            => 'regionName' . $language,
                        'class'         => 'form-control'
                    ]
                ]);
            }
        } else {
            $this->add([
                'type'  => 'textarea',
                'name'  => 'regionName' . MultiLanguage::REGION_DEFAULT_LANGUAGE,
                'attributes'    => [
                    'id'            => 'regionName' . MultiLanguage::REGION_DEFAULT_LANGUAGE,
                    'class'         => 'form-control',
                    'rows'          => 6
                ]
            ]);
        }

        $this->add([
            'type'  => 'number',
            'name'  => 'regionSort',
            'attributes'    => [
                'id'            => 'regionSort',
                'class'         => 'form-control',
                'value'         => 255
            ]
        ]);

        $this->add([
            'type'  => 'hidden',
            'name'  => 'regionTopId',
            'attributes'    => [
                'id'            => 'regionTopId',
                'value'         => 0
            ]
        ]);
    }

    protected function addInputFilter()
    {
        $inputFilter = $this->getInputFilter();

        if (MultiLanguage::REGION_MULTI_LANGUAGE == 1) {
            foreach (SHOP_LANGUAGE as $language) {
                $inputFilter->add([
                    'name'      => 'regionName' . $language,
                    'required'  => true,
                    'filters'   => [
                        ['name' => 'StringTrim'],
                        ['name' => 'StripTags']
                    ]
                ]);
            }
        } else {
            $inputFilter->add([
                'name'      => 'regionName' . MultiLanguage::REGION_DEFAULT_LANGUAGE,
                'required'  => true,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ]
            ]);
        }

        $inputFilter->add([
            'name'      => 'regionSort',
            'required'  => true,
            'filters'   => [
                ['name' => 'ToInt']
            ],
            'validators'=> [
                [
                    'name'      => 'GreaterThan',
                    'options'   => [
                        'min'   => 0
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'regionTopId',
            'required'  => true,
            'filters'   => [
                ['name' => 'ToInt']
            ]
        ]);
    }
}