<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Admin\Repository;

use Admin\Data\MultiLanguage;
use Admin\Entity\Region;
use Admin\Entity\RegionContent;
use Admin\Repository\QuerySearch\RegionSearch;
use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Query\Expr\Join;

class RegionRepository extends EntityRepository
{
    /**
     * 地区信息
     * @param $orderType
     * @return float|int|mixed|string
     */
    public function findAllRegion($orderType = 'regionPath')
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('r', 'c.regionName')
            ->from(Region::class, 'r')
            ->leftJoin(RegionContent::class, 'c', Join::WITH, 'r.regionId = c.regionId')
            ->andWhere('c.languageCode = :languageCode')->setParameter('languageCode', MultiLanguage::REGION_MULTI_LANGUAGE == 1 ? SHOP_FONT_LANGUAGE : MultiLanguage::REGION_DEFAULT_LANGUAGE)
            ->orderBy('r.'.$orderType, 'ASC');

        return $query->getQuery()->getResult();
    }

    /**
     * 地区列表
     * @param $regionTopId
     * @param array $search
     * @return float|int|mixed|string
     */
    public function findRegionList($regionTopId, array $search = [])
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('r', 'c.regionName')
            ->from(Region::class, 'r')
            ->leftJoin(RegionContent::class, 'c', Join::WITH, 'r.regionId = c.regionId')
            ->where('r.regionTopId = :regionTopId')->setParameter('regionTopId', $regionTopId)
            ->andWhere('c.languageCode = :languageCode')->setParameter('languageCode', MultiLanguage::REGION_MULTI_LANGUAGE == 1 ? SHOP_FONT_LANGUAGE : MultiLanguage::REGION_DEFAULT_LANGUAGE)
            ->orderBy('r.regionSort', 'ASC');

        $query = RegionSearch::querySearch($search, $query);

        return $query->getQuery()->getResult();
    }
    /*====================================商城前台====================================*/

    /**
     * 前台地区列表
     * @param $languageCode
     * @param $regionTopId
     * @param array $search
     * @return float|int|mixed|string
     */
    public function findShopRegionList($languageCode, $regionTopId, array $search = [])
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('r', 'c.regionName')
            ->from(Region::class, 'r')
            ->leftJoin(RegionContent::class, 'c', Join::WITH, 'r.regionId = c.regionId')
            ->where('r.regionTopId = :regionTopId')->setParameter('regionTopId', $regionTopId)
            ->andWhere('c.languageCode = :languageCode')->setParameter('languageCode', MultiLanguage::REGION_MULTI_LANGUAGE == 1 ? $languageCode : MultiLanguage::REGION_DEFAULT_LANGUAGE)
            ->orderBy('r.regionSort', 'ASC');

        $query = RegionSearch::querySearch($search, $query);

        return $query->getQuery()->getResult();
    }
}