<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Admin\Service;

use Admin\Entity\DeliveryContent;
use Doctrine\ORM\EntityManager;

class DeliveryContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 编辑配送内容
     * @param array $data
     * @param $deliveryId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditDeliveryContent(array $data, $deliveryId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $deliveryContent= $this->entityManager->getRepository(DeliveryContent::class)->findOneBy(['deliveryId' => $deliveryId, 'languageCode' => $language]);
            $emptyState     = false;
            if ($deliveryContent == null) {
                $deliveryContent = new DeliveryContent();
                $deliveryContent->setDeliveryId($deliveryId);
                $deliveryContent->setLanguageCode($language);
                $emptyState = true;
            }
            $deliveryContent->setDeliveryName($data['deliveryName' . $language]);
            $deliveryContent->setDeliveryInfo($data['deliveryInfo' . $language]);

            if ($emptyState) $this->entityManager->persist($deliveryContent);

            $this->entityManager->flush();
        }
    }

    /**
     * 删除配送内容
     * @param $deliveryId
     * @return void
     */
    public function deleteDeliveryContent($deliveryId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(DeliveryContent::class, 'd')->where($qb->expr()->eq('c.deliveryId', $deliveryId));
        $qb->getQuery()->execute();
    }
}