<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Admin\Service;

use Admin\Entity\Region;
use Admin\Entity\RegionContent;
use Admin\Entity\SelfLocationContent;
use Doctrine\ORM\EntityManager;

class SelfLocationContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;

    }

    /**
     * 编辑内容
     * @param array $data
     * @param $locationId
     * @param $regionId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditSelfLocationContent(array $data, $locationId, $regionId)
    {
        $regionInfoArray = $this->entityManager->getRepository(RegionContent::class)->findRegionContentArray($regionId);

        foreach (SHOP_LANGUAGE as $language) {
            $locationContent= $this->entityManager->getRepository(SelfLocationContent::class)->findOneBy(['locationId' => $locationId, 'languageCode' => $language]);
            $emptyState     = false;
            if ($locationContent == null) {
                $locationContent = new SelfLocationContent();
                $locationContent->setLanguageCode($language);
                $locationContent->setLocationId($locationId);
                $emptyState = true;
            }
            $locationContent->setLocationName($data['locationName'.$language]);
            $locationContent->setLocationAddress($data['locationAddress'.$language]);
            $locationContent->setLocationUser($data['locationUser'.$language]);
            $locationContent->setLocationBusinessHours($data['locationBusinessHours'.$language]);
            $locationContent->setRegionInfo(($regionInfoArray['regionInfo'.$language] ?? ''));

            if ($emptyState) $this->entityManager->persist($locationContent);

            $this->entityManager->flush();
        }
    }

    /**
     * 删除自提点内容
     * @param $locationId
     * @return void
     */
    public function deleteSelfLocationContent($locationId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(SelfLocationContent::class, 's')->where($qb->expr()->eq('s.locationId', $locationId));
        $qb->getQuery()->execute();
    }
}