<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Analysis;

use Admin\Data\Config;
use Analysis\Controller\Factory\IndexControllerFactory;
use Analysis\Controller\IndexController;
use Analysis\Event\AnalysisExtendListener;
use Analysis\Event\Factory\AnalysisExtendListenerFactory;
use Doctrine\ORM\Mapping\Driver\AnnotationDriver;
use Laminas\Router\Http\Segment;

return [
    'router' => [
        'routes' => [
            'analysis' => [
                'type' => Segment::class,
                'options' => [
                    'route' => '/' . Config::ADMIN_PATH . '/analysis[/:action]',
                    'defaults' => [
                        'controller' => IndexController::class,
                        'action'    => 'index'
                    ]
                ]
            ],

        ]

    ],

    'controllers' => [
        'factories' => [
            IndexController::class => IndexControllerFactory::class
        ]
    ],

    'service_manager' => [
        'factories' => [
            AnalysisExtendListener::class => AnalysisExtendListenerFactory::class
        ]
    ],

    'listeners' => [
        AnalysisExtendListener::class
    ],

    'permission_filter' => include __DIR__ . '/permission.php',

    'controller_plugins' => [
        'factories' => [

        ],
        'aliases'   => [

        ]
    ],

    'view_helpers' => [
        'factories' => [

        ],
        'aliases' => [

        ],
    ],

    'translator' => [
        'translation_file_patterns' => [
            [
                'type' => 'gettext',
                'base_dir' => __DIR__ . '/../data/language',
                'pattern' => '%s.mo'
            ],
            [
                'type' => 'gettext',
                'base_dir' => __DIR__ . '/../data/language/extend',
                'pattern' => '%s.mo'
            ]
        ]
    ],

    'view_manager' => [
        'template_path_stack' => [
            __DIR__ . '/../view',
        ],
        'strategies' => [
            'ViewJsonStrategy',
        ]
    ]
];