<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Cms\Repository;

use Admin\Data\Common;
use Cms\Entity\SingleCms;
use Cms\Entity\SingleCmsContent;
use Cms\Repository\QuerySearch\SingleCmsSearch;
use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Query\Expr\Join;
use function Doctrine\ORM\QueryBuilder;

class SingleCmsRepository extends EntityRepository
{
    /**
     * 后台单页列表显示，对应不同模板
     * @return float|int|mixed|string
     */
    public function findSingleCmsList()
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('s')
            ->addSelect("(SELECT c.singleCmsTitle FROM ".SingleCmsContent::class." AS c WHERE c.singleCmsId=s.singleCmsId AND c.languageCode='".SHOP_FONT_LANGUAGE."') AS singleCmsTitle")
            ->from(SingleCms::class, 's')
            ->orderBy('s.singleCmsSort', 'ASC')
            ->addOrderBy('s.singleCmsId', 'ASC');

        $template           = Common::readConfigFile('template');
        $pcTemplateStr      = str_replace('/', '-', $template['pcTemplate']);
        $mobileTemplateStr  = str_replace('/', '-', $template['mobileTemplate']);
        switch ($template['displayType']) {
            case 'auto':
                if (!empty($pcTemplateStr)) $query->orWhere('s.templateCode = :pcCode')->setParameter('pcCode', $pcTemplateStr);
                if (!empty($mobileTemplateStr))  $query->orWhere('s.templateCode = :mobCode')->setParameter('mobCode', $mobileTemplateStr);
            break;
            case 'pc':
                $query->where('s.templateCode = :pcCode')->setParameter('pcCode', $pcTemplateStr);
                break;
            case 'mobile':
                $query->where('s.templateCode = :mobCode')->setParameter('mobCode', $mobileTemplateStr);
                break;
        }
        $query->orWhere($query->expr()->isNull('s.templateCode'));

        return $query->getQuery()->getResult();
    }

    /**
     * 后台单页文章列表返回
     * @param array $search
     * @return \Doctrine\ORM\Query
     */
    public function findAllSingleCms(array $search = [])
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('s')
            ->addSelect("(SELECT c.singleCmsTitle FROM ".SingleCmsContent::class." AS c WHERE c.singleCmsId=s.singleCmsId AND c.languageCode='".SHOP_FONT_LANGUAGE."') AS singleCmsTitle")
            ->from(SingleCms::class, 's')
            ->orderBy('s.singleCmsId', 'DESC');

        $query = SingleCmsSearch::querySearchData($search, $query);

        return $query->getQuery();
    }

    /*==============================================下面为前台调用==============================================*/

    /**
     * 前台单页文章调用(多个调用)
     * @param $singleTag
     * @param $templateCode
     * @param $languageCode
     * @return float|int|mixed|string
     */
    public function findShopSingleCmsTagTemplateCode($singleTag, $templateCode, $languageCode)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('s', 'c.singleCmsTitle', 'c.singleCmsBody')
            ->from(SingleCms::class, 's')
            ->innerJoin(SingleCmsContent::class, 'c', Join::WITH, 's.singleCmsId = c.singleCmsId')
            ->where('s.singleTag = :singleTag')->setParameter('singleTag', $singleTag)
            ->andWhere('s.templateCode = :templateCode')->setParameter('templateCode', $templateCode)
            ->andWhere('c.languageCode = :languageCode')->setParameter('languageCode', $languageCode)
            ->orderBy('s.singleCmsSort', 'ASC');

        return $query->getQuery()->getResult();
    }
}