<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Cms\Service;

use Admin\Data\Common;
use Admin\Data\Config;
use Cms\Entity\SingleCmsContent;
use Doctrine\ORM\EntityManager;

class SingleCmsContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加或者编辑单页多语言内容
     * @param array $data
     * @param $singleCmsId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditSingleCmsContent(array $data, $singleCmsId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $singleCmsContent = $this->entityManager->getRepository(SingleCmsContent::class)->findOneBy(['singleCmsId' => $singleCmsId, 'languageCode' => $language]);
            $emptyState = false;
            if ($singleCmsContent == null) {
                $singleCmsContent = new SingleCmsContent();
                $singleCmsContent->setLanguageCode($language);
                $singleCmsContent->setSingleCmsId($singleCmsId);
                $emptyState = true;
            }
            $singleCmsContent->setSingleCmsTitle($data['singleCmsTitle'.$language]);
            $singleCmsContent->setSingleCmsExtendTitle($data['singleCmsExtendTitle'.$language]);
            $singleCmsContent->setSingleCmsBody($data['singleCmsBody'.$language]);
            $singleCmsContent->setSingleCmsKeywords($data['singleCmsKeywords'.$language]);
            $singleCmsContent->setSingleCmsDescription($data['singleCmsDescription'.$language]);

            if ($emptyState) $this->entityManager->persist($singleCmsContent);

            $this->entityManager->flush();
        }
    }

    /**
     * 删除单页文章多语言
     * @param $singleCmsId
     * @return array|null
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function deleteSingleCmsContent($singleCmsId)
    {
        $singleCmsContent = $this->entityManager->getRepository(SingleCmsContent::class)->findBy(['singleCmsId' => $singleCmsId]);
        $body = '';
        foreach ($singleCmsContent as $contentValue) {
            $body .= $contentValue->getSingleCmsBody();

            $this->entityManager->remove($contentValue);
            $this->entityManager->flush();
        }

        $imageList = Common::bodyImageArray($body);

        if ($imageList) foreach ($imageList as $imageValue) {
            if (stripos($imageValue, 'http') !== false) continue;
            @unlink(Config::CMS_IMAGE_PATH . basename($imageValue));
        }

        return $imageList;
    }
}