<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Extend\Service;

use Doctrine\ORM\EntityManager;
use Extend\Entity\NavigationContent;

class NavigationContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加或者编辑导航内容
     * @param array $data
     * @param $navigationId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditNavigationContent(array $data, $navigationId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $navigationContent = $this->entityManager->getRepository(NavigationContent::class)->findOneBy(['navigationId' => $navigationId, 'languageCode' => $language]);
            if ($navigationContent) {
                $navigationContent->setNavigationTitle($data['navigationTitle'.$language]);
            } else {
                $navigationContent = new NavigationContent();
                $navigationContent->setLanguageCode($language);
                $navigationContent->setNavigationId($navigationId);
                $navigationContent->setNavigationTitle($data['navigationTitle'.$language]);

                $this->entityManager->persist($navigationContent);
            }

            $this->entityManager->flush();
        }
    }

    /**
     * 删除导航内容
     * @param $navigationId
     * @return void
     */
    public function deleteNavigationContent($navigationId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(NavigationContent::class, 'c')->where($qb->expr()->eq('c.navigationId', $navigationId));
        $qb->getQuery()->execute();
    }
}