<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Shop\Controller;

use Cms\Entity\Cms;
use Cms\Entity\CmsClass;
use Cms\Entity\CmsClassContent;
use Cms\Entity\CmsContent;
use Cms\Entity\SingleCms;
use Cms\Entity\SingleCmsContent;
use Doctrine\ORM\EntityManager;
use Laminas\Mvc\Controller\AbstractActionController;
use Laminas\Mvc\I18n\Translator;

class CmsController extends AbstractActionController
{
    private $translator;
    private $entityManager;

    public function __construct(
        Translator      $translator,
        EntityManager   $entityManager
    )
    {
        $this->translator   = $translator;
        $this->entityManager= $entityManager;
    }

    public function indexAction()
    {
        $cmsClassId = $this->params()->fromRoute('id', 0);
        $cmsClassInfo = $this->entityManager->getRepository(CmsClass::class)->findOneBy(['cmsClassId' => $cmsClassId, 'cmsClassState' => 1]);
        if ($cmsClassInfo == null) return $this->redirect()->toRoute('shop');

        $cmsClassContent = $this->entityManager->getRepository(CmsClassContent::class)->findOneBy(['cmsClassId' => $cmsClassId, 'languageCode' => $this->shopPlugin()->shopLanguageCode()]);

        $this->layout()->setVariables([
            'titleName'         => $cmsClassContent->getCmsClassName(),
            'extendTitleName'   => $cmsClassContent->getCmsClassExtendName(),
            'extendKeywords'    => $cmsClassContent->getCmsClassKeywords(),
            'extendDescription' => $cmsClassContent->getCmsClassDescription()
        ]);

        $page       = (int) $this->params()->fromQuery('page', 1);
        $query      = $this->entityManager->getRepository(Cms::class)->shopListCms($this->shopPlugin()->shopLanguageCode(), $cmsClassId, []);
        $paginator  = $this->shopPlugin()->shopPaginator($query, $page, $this->shopPlugin()->shopPerPageNum('cmsList'));

        $cmsSubClass = [];
        if ($cmsClassInfo->getCmsClassTopId() == 0) $cmsSubClass = $this->entityManager->getRepository(CmsClass::class)->shopSubCmsClass($cmsClassInfo->getCmsClassId(), $this->shopPlugin()->shopLanguageCode());
        $cmsClass    = $this->entityManager->getRepository(CmsClass::class)->shopSubCmsClass($cmsClassInfo->getCmsClassTopId(), $this->shopPlugin()->shopLanguageCode());

        return [
            'cmsClassInfo'      => $cmsClassInfo,
            'cmsClassContent'   => $cmsClassContent,
            'cmsList'           => $paginator,

            'cmsClass'      => $cmsClass,       //同级分类
            'cmsSubClass'   => $cmsSubClass     //下级分类
        ];
    }

    /**
     * 文章内容
     * @return array|\Laminas\Http\Response
     */
    public function contentAction()
    {
        $cmsId = $this->params()->fromRoute('id', 0);
        $cmsInfo = $this->entityManager->getRepository(Cms::class)->findOneBy(['cmsId' => $cmsId, 'cmsState' => 1]);
        if ($cmsInfo == null) return $this->redirect()->toRoute('shop');
        if (!empty($cmsInfo->getCmsUrl())) return $this->redirect()->toUrl($cmsInfo->getCmsUrl());

        $cmsContent = $this->entityManager->getRepository(CmsContent::class)->findOneBy(['cmsId' => $cmsId, 'languageCode' => $this->shopPlugin()->shopLanguageCode()]);

        $this->layout()->setVariables([
            'titleName'         => $cmsContent->getCmsTitle(),
            'extendTitleName'   => $cmsContent->getCmsExtendTitle(),
            'extendKeywords'    => $cmsContent->getCmsKeywords(),
            'extendDescription' => $cmsContent->getCmsDescription()
        ]);

        $cmsClassInfo   = $this->entityManager->getRepository(CmsClass::class)->findOneBy(['cmsClassId' => $cmsInfo->getCmsClassId()]);
        $cmsClassContent = $this->entityManager->getRepository(CmsClassContent::class)->findOneBy(['cmsClassId' => $cmsInfo->getCmsClassId(), 'languageCode' => $this->shopPlugin()->shopLanguageCode()]);
        $cmsClass = [];
        if ($cmsClassInfo->getCmsClassTopId() > 0) $cmsClass = $this->entityManager->getRepository(CmsClass::class)->shopSubCmsClass($cmsClassInfo->getCmsClassTopId(), $this->shopPlugin()->shopLanguageCode());
        $cmsTopClass    = $this->entityManager->getRepository(CmsClass::class)->shopSubCmsClass(0, $this->shopPlugin()->shopLanguageCode());

        return [
            'cmsInfo'       => $cmsInfo,
            'cmsContent'    => $cmsContent,
            'cmsClassInfo'  => $cmsClassInfo,   //当前文章分类详情
            'cmsClassContent' => $cmsClassContent,
            'cmsClass'      => $cmsClass,       //同级分类
            'cmsTopClass'   => $cmsTopClass     //顶级分类
        ];
    }

    /**
     * 单页文章内容
     * @return array|\Laminas\Http\Response
     */
    public function singleAction()
    {
        $singleId = $this->params()->fromRoute('id', 0);
        $singleInfo = $this->entityManager->getRepository(SingleCms::class)->findOneBy(['singleCmsId' => $singleId]);
        if ($singleInfo == null) return $this->redirect()->toRoute('shop');

        $singleContent = $this->entityManager->getRepository(SingleCmsContent::class)->findOneBy(['singleCmsId' => $singleId, 'languageCode' => $this->shopPlugin()->shopLanguageCode()]);

        $this->layout()->setVariables([
            'titleName'         => $singleContent->getSingleCmsTitle(),
            'extendTitleName'   => $singleContent->getSingleCmsExtendTitle(),
            'extendKeywords'    => $singleContent->getSingleCmsKeywords(),
            'extendDescription' => $singleContent->getSingleCmsDescription()
        ]);

        return ['singleInfo' => $singleInfo, 'singleContent' => $singleContent];
    }
}